import { z } from "zod";
import type { Connection } from "../interfaces/Connection.js";
import type { TypesConfig } from "../interfaces/TypesConfig.js";
export interface Config {
    /**
     * The environment variable containing the
     * connection string to the postgres database
     *
     * Note that if the enviroment variable is set, the `connections` option is ignored.
     *
     * If you want to connect to multiple databases, you can use the same environment variable with a "_1" suffix for the second database, "_2" for the third database, etc.
     *
     * @default "DATABASE_URL"
     */
    connectionStringEnvironmentVariable: string;
    /**
     * The connection string to the postgres database
     * or a connection object with the following properties:
     * - host: The hostname of the postgres database
     * - port: The port of the postgres database
     * - user: The username of the postgres database
     * - password: The password of the postgres database
     * - database: The name of the postgres database
     *
     * To set the connection string using environment variables, you need to set the `connectionStringEnvironmentVariable` to the name of the environment variable.
     * If you want to connect to multiple databases, you can use an array of connection strings or connection objects.
     * @default "postgres://postgres:postgres@localhost:5432/postgres?sslmode=disable"
     */
    connections: string | string[] | Connection | Connection[];
    /**
     * The schemas to generate the typescript types for
     *
     * You can input the following values:
     * - "*" to generate types for all schemas.
     * - A string with the name of a the schema to generate types for.
     * - An array of schema names to generate types for.
     * - A number with the oid of a the schema to generate types for.
     * - An array of oids to generate types for.
     *
     * Note that if you input a string, then you need to prefix the schema name with the database name, you can use the following syntax:
     * - `database.schema`
     *
     * @default "*"
     */
    schemas: string | string[] | number | number[];
    /**
     * The tables to generate the typescript types for
     *
     * You can input the following values:
     * - "*" to generate types for all tables.
     * - A string with the name of a the table to generate types for.
     * - An array of table names to generate types for.
     * - A number with the oid of a the table to generate types for.
     * - An array of oids to generate types for.
     *
     * Note that if you input a string, then you need to prefix the table with the name of the schema and name of the database, you can use the following syntax:
     * - `database.schema.table`
     *
     * @default "*"
     */
    tables: string | string[] | number | number[];
    /**
     * Config for the types generator
     *
     * @default {}
     */
    types: TypesConfig;
    /**
     * The TypeScript module type you use in your project (if you are using esm it adds the .js import extension)
     *
     * @default "cjs"
     */
    type: "esm" | "cjs";
}
export declare const zConfig: z.ZodObject<{
    connectionStringEnvironmentVariable: z.ZodDefault<z.ZodString>;
    connections: z.ZodDefault<z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "many">]>, z.ZodObject<{
        host: z.ZodDefault<z.ZodString>;
        port: z.ZodDefault<z.ZodNumber>;
        user: z.ZodDefault<z.ZodString>;
        password: z.ZodOptional<z.ZodString>;
        database: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        password?: string | undefined;
        host: string;
        port: number;
        user: string;
        database: string;
    }, {
        host?: string | undefined;
        port?: number | undefined;
        user?: string | undefined;
        password?: string | undefined;
        database?: string | undefined;
    }>]>, z.ZodArray<z.ZodObject<{
        host: z.ZodDefault<z.ZodString>;
        port: z.ZodDefault<z.ZodNumber>;
        user: z.ZodDefault<z.ZodString>;
        password: z.ZodOptional<z.ZodString>;
        database: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        password?: string | undefined;
        host: string;
        port: number;
        user: string;
        database: string;
    }, {
        host?: string | undefined;
        port?: number | undefined;
        user?: string | undefined;
        password?: string | undefined;
        database?: string | undefined;
    }>, "many">]>>;
    schemas: z.ZodDefault<z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "many">]>, z.ZodNumber]>, z.ZodArray<z.ZodNumber, "many">]>>;
    tables: z.ZodDefault<z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "many">]>, z.ZodNumber]>, z.ZodArray<z.ZodNumber, "many">]>>;
    types: z.ZodDefault<z.ZodObject<{
        directory: z.ZodDefault<z.ZodString>;
        debug: z.ZodDefault<z.ZodBoolean>;
        debugFileName: z.ZodDefault<z.ZodString>;
        domainTypeName: z.ZodDefault<z.ZodString>;
        domainFileName: z.ZodDefault<z.ZodString>;
        domainDataTypeName: z.ZodDefault<z.ZodString>;
        domainDataFileName: z.ZodDefault<z.ZodString>;
        enumTypeName: z.ZodDefault<z.ZodString>;
        enumFileName: z.ZodDefault<z.ZodString>;
        primaryKeyTypeName: z.ZodDefault<z.ZodString>;
        primaryKeyFileName: z.ZodDefault<z.ZodString>;
        tableTypeName: z.ZodDefault<z.ZodString>;
        tableFileName: z.ZodDefault<z.ZodString>;
        tableDataTypeName: z.ZodDefault<z.ZodString>;
        tableDataFileName: z.ZodDefault<z.ZodString>;
        tableInsertParametersTypeName: z.ZodDefault<z.ZodString>;
        tableInsertParametersFileName: z.ZodDefault<z.ZodString>;
        tableInsertParametersDataTypeName: z.ZodDefault<z.ZodString>;
        tableInsertParametersDataFileName: z.ZodDefault<z.ZodString>;
        schemaTypeName: z.ZodDefault<z.ZodString>;
        schemaFileName: z.ZodDefault<z.ZodString>;
        schemaDataTypeName: z.ZodDefault<z.ZodString>;
        schemaDataFileName: z.ZodDefault<z.ZodString>;
        databaseTypeName: z.ZodDefault<z.ZodString>;
        databaseFileName: z.ZodDefault<z.ZodString>;
        databaseDataTypeName: z.ZodDefault<z.ZodString>;
        databaseDataFileName: z.ZodDefault<z.ZodString>;
        fullExportTypeName: z.ZodDefault<z.ZodString>;
        fullExportFileName: z.ZodDefault<z.ZodString>;
        fullExportDataTypeName: z.ZodDefault<z.ZodString>;
        fullExportDataFileName: z.ZodDefault<z.ZodString>;
        columnTypeOverrides: z.ZodDefault<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodString>>>;
        typeOverrides: z.ZodDefault<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodString>>>;
        columnParserOverrides: z.ZodDefault<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodTuple<[z.ZodString, z.ZodArray<z.ZodObject<{
            module: z.ZodString;
            name: z.ZodString;
            as: z.ZodOptional<z.ZodString>;
            type: z.ZodUnion<[z.ZodLiteral<"default">, z.ZodLiteral<"named">]>;
            isType: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            as?: string | undefined;
            isType?: boolean | undefined;
            type: "default" | "named";
            module: string;
            name: string;
        }, {
            as?: string | undefined;
            isType?: boolean | undefined;
            type: "default" | "named";
            module: string;
            name: string;
        }>, "many">], null>>>>;
        parserOverrides: z.ZodDefault<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodTuple<[z.ZodString, z.ZodArray<z.ZodObject<{
            module: z.ZodString;
            name: z.ZodString;
            as: z.ZodOptional<z.ZodString>;
            type: z.ZodUnion<[z.ZodLiteral<"default">, z.ZodLiteral<"named">]>;
            isType: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            as?: string | undefined;
            isType?: boolean | undefined;
            type: "default" | "named";
            module: string;
            name: string;
        }, {
            as?: string | undefined;
            isType?: boolean | undefined;
            type: "default" | "named";
            module: string;
            name: string;
        }>, "many">], null>>>>;
    }, "strip", z.ZodTypeAny, {
        debug: boolean;
        directory: string;
        debugFileName: string;
        domainTypeName: string;
        domainFileName: string;
        domainDataTypeName: string;
        domainDataFileName: string;
        enumTypeName: string;
        enumFileName: string;
        primaryKeyTypeName: string;
        primaryKeyFileName: string;
        tableTypeName: string;
        tableFileName: string;
        tableDataTypeName: string;
        tableDataFileName: string;
        tableInsertParametersTypeName: string;
        tableInsertParametersFileName: string;
        tableInsertParametersDataTypeName: string;
        tableInsertParametersDataFileName: string;
        schemaTypeName: string;
        schemaFileName: string;
        schemaDataTypeName: string;
        schemaDataFileName: string;
        databaseTypeName: string;
        databaseFileName: string;
        databaseDataTypeName: string;
        databaseDataFileName: string;
        fullExportTypeName: string;
        fullExportFileName: string;
        fullExportDataTypeName: string;
        fullExportDataFileName: string;
        columnTypeOverrides: Record<string, string | undefined>;
        typeOverrides: Record<string, string | undefined>;
        columnParserOverrides: Record<string, [string, {
            as?: string | undefined;
            isType?: boolean | undefined;
            type: "default" | "named";
            module: string;
            name: string;
        }[]] | undefined>;
        parserOverrides: Record<string, [string, {
            as?: string | undefined;
            isType?: boolean | undefined;
            type: "default" | "named";
            module: string;
            name: string;
        }[]] | undefined>;
    }, {
        debug?: boolean | undefined;
        directory?: string | undefined;
        debugFileName?: string | undefined;
        domainTypeName?: string | undefined;
        domainFileName?: string | undefined;
        domainDataTypeName?: string | undefined;
        domainDataFileName?: string | undefined;
        enumTypeName?: string | undefined;
        enumFileName?: string | undefined;
        primaryKeyTypeName?: string | undefined;
        primaryKeyFileName?: string | undefined;
        tableTypeName?: string | undefined;
        tableFileName?: string | undefined;
        tableDataTypeName?: string | undefined;
        tableDataFileName?: string | undefined;
        tableInsertParametersTypeName?: string | undefined;
        tableInsertParametersFileName?: string | undefined;
        tableInsertParametersDataTypeName?: string | undefined;
        tableInsertParametersDataFileName?: string | undefined;
        schemaTypeName?: string | undefined;
        schemaFileName?: string | undefined;
        schemaDataTypeName?: string | undefined;
        schemaDataFileName?: string | undefined;
        databaseTypeName?: string | undefined;
        databaseFileName?: string | undefined;
        databaseDataTypeName?: string | undefined;
        databaseDataFileName?: string | undefined;
        fullExportTypeName?: string | undefined;
        fullExportFileName?: string | undefined;
        fullExportDataTypeName?: string | undefined;
        fullExportDataFileName?: string | undefined;
        columnTypeOverrides?: Record<string, string | undefined> | undefined;
        typeOverrides?: Record<string, string | undefined> | undefined;
        columnParserOverrides?: Record<string, [string, {
            as?: string | undefined;
            isType?: boolean | undefined;
            type: "default" | "named";
            module: string;
            name: string;
        }[]] | undefined> | undefined;
        parserOverrides?: Record<string, [string, {
            as?: string | undefined;
            isType?: boolean | undefined;
            type: "default" | "named";
            module: string;
            name: string;
        }[]] | undefined> | undefined;
    }>>;
    type: z.ZodDefault<z.ZodUnion<[z.ZodLiteral<"esm">, z.ZodLiteral<"cjs">]>>;
}, "strip", z.ZodTypeAny, {
    type: "esm" | "cjs";
    connectionStringEnvironmentVariable: string;
    connections: string | string[] | {
        password?: string | undefined;
        host: string;
        port: number;
        user: string;
        database: string;
    } | {
        password?: string | undefined;
        host: string;
        port: number;
        user: string;
        database: string;
    }[];
    schemas: string | number | string[] | number[];
    tables: string | number | string[] | number[];
    types: {
        debug: boolean;
        directory: string;
        debugFileName: string;
        domainTypeName: string;
        domainFileName: string;
        domainDataTypeName: string;
        domainDataFileName: string;
        enumTypeName: string;
        enumFileName: string;
        primaryKeyTypeName: string;
        primaryKeyFileName: string;
        tableTypeName: string;
        tableFileName: string;
        tableDataTypeName: string;
        tableDataFileName: string;
        tableInsertParametersTypeName: string;
        tableInsertParametersFileName: string;
        tableInsertParametersDataTypeName: string;
        tableInsertParametersDataFileName: string;
        schemaTypeName: string;
        schemaFileName: string;
        schemaDataTypeName: string;
        schemaDataFileName: string;
        databaseTypeName: string;
        databaseFileName: string;
        databaseDataTypeName: string;
        databaseDataFileName: string;
        fullExportTypeName: string;
        fullExportFileName: string;
        fullExportDataTypeName: string;
        fullExportDataFileName: string;
        columnTypeOverrides: Record<string, string | undefined>;
        typeOverrides: Record<string, string | undefined>;
        columnParserOverrides: Record<string, [string, {
            as?: string | undefined;
            isType?: boolean | undefined;
            type: "default" | "named";
            module: string;
            name: string;
        }[]] | undefined>;
        parserOverrides: Record<string, [string, {
            as?: string | undefined;
            isType?: boolean | undefined;
            type: "default" | "named";
            module: string;
            name: string;
        }[]] | undefined>;
    };
}, {
    type?: "esm" | "cjs" | undefined;
    connectionStringEnvironmentVariable?: string | undefined;
    connections?: string | string[] | {
        host?: string | undefined;
        port?: number | undefined;
        user?: string | undefined;
        password?: string | undefined;
        database?: string | undefined;
    } | {
        host?: string | undefined;
        port?: number | undefined;
        user?: string | undefined;
        password?: string | undefined;
        database?: string | undefined;
    }[] | undefined;
    schemas?: string | number | string[] | number[] | undefined;
    tables?: string | number | string[] | number[] | undefined;
    types?: {
        debug?: boolean | undefined;
        directory?: string | undefined;
        debugFileName?: string | undefined;
        domainTypeName?: string | undefined;
        domainFileName?: string | undefined;
        domainDataTypeName?: string | undefined;
        domainDataFileName?: string | undefined;
        enumTypeName?: string | undefined;
        enumFileName?: string | undefined;
        primaryKeyTypeName?: string | undefined;
        primaryKeyFileName?: string | undefined;
        tableTypeName?: string | undefined;
        tableFileName?: string | undefined;
        tableDataTypeName?: string | undefined;
        tableDataFileName?: string | undefined;
        tableInsertParametersTypeName?: string | undefined;
        tableInsertParametersFileName?: string | undefined;
        tableInsertParametersDataTypeName?: string | undefined;
        tableInsertParametersDataFileName?: string | undefined;
        schemaTypeName?: string | undefined;
        schemaFileName?: string | undefined;
        schemaDataTypeName?: string | undefined;
        schemaDataFileName?: string | undefined;
        databaseTypeName?: string | undefined;
        databaseFileName?: string | undefined;
        databaseDataTypeName?: string | undefined;
        databaseDataFileName?: string | undefined;
        fullExportTypeName?: string | undefined;
        fullExportFileName?: string | undefined;
        fullExportDataTypeName?: string | undefined;
        fullExportDataFileName?: string | undefined;
        columnTypeOverrides?: Record<string, string | undefined> | undefined;
        typeOverrides?: Record<string, string | undefined> | undefined;
        columnParserOverrides?: Record<string, [string, {
            as?: string | undefined;
            isType?: boolean | undefined;
            type: "default" | "named";
            module: string;
            name: string;
        }[]] | undefined> | undefined;
        parserOverrides?: Record<string, [string, {
            as?: string | undefined;
            isType?: boolean | undefined;
            type: "default" | "named";
            module: string;
            name: string;
        }[]] | undefined> | undefined;
    } | undefined;
}>;
export declare const DEFAULT_CONFIG: Config;
