import { z } from "zod";
import { type ImportStatement } from "./ImportStatement.js";
export interface TypesConfig {
    /**
     * The directory (relative to this config) to put the generated code in
     *
     * @default "__generated__"
     */
    directory: string;
    /**
     * Whether to add debugging statements to the generated code
     * @default false
     */
    debug: boolean;
    /**
     * What should the debug file be called
     *
     * You may use the following placeholders:
     * - `DATE`: The current date (YYYY-MM-DD)
     * - `TIME`: The current time (HH:MM:SS.sss)
     * - `TIMESTAMP`: The current timestamp (YYYY-MM-DD_HH:MM:SS.sss)
     * - `YEAR`: The current year (YYYY)
     * - `MONTH`: The current month (MM)
     * - `DAY`: The current day (DD)
     * - `HOUR`: The current hour (HH)
     * - `MINUTE`: The current minute (MM)
     * - `SECOND`: The current second (SS)
     * - `MILLISECOND`: The current millisecond (sss)
     *
     * Note: The timestamp is in UTC time
     * Note: .json is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "debug_{{ TIMESTAMP }}.json"
     */
    debugFileName: string;
    /**
     * What should custom types be called in the generated code
     *
     * You may use the following placeholders:
     * - `TYPE_NAME`: The name of the type
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * @default "{{ TYPE_NAME | pascal-case }}"
     */
    domainTypeName: string;
    /**
     * Where should custom types be located in the generated code
     *
     * You may use the following placeholders:
     * - `TYPE_NAME`: The name of the type
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "_custom_types.ts"
     */
    domainFileName: string;
    /**
     * What should domain data be called in the generated code
     *
     * You may use the following placeholders:
     * - `TYPE_NAME`: The name of the type
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * @default "{{ TYPE_NAME | pascal-case }}_Data"
     */
    domainDataTypeName: string;
    /**
     * Where should domain data be located in the generated code
     *
     * You may use the following placeholders:
     * - `TYPE_NAME`: The name of the type
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "_custom_types.ts"
     */
    domainDataFileName: string;
    /**
     * What should enum types be called in the generated code
     *
     * You may use the following placeholders:
     * - `TYPE_NAME`: The name of the type
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * @default "{{ TYPE_NAME | pascal-case }}"
     */
    enumTypeName: string;
    /**
     * Where should enum types be located in the generated code
     *
     * You may use the following placeholders:
     * - `TYPE_NAME`: The name of the type
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "databases/{{ DATABASE_NAME }}/enums/{{ TYPE_NAME }}.ts"
     */
    enumFileName: string;
    /**
     * What should primary key types be called in the generated code
     *
     * You may use the following placeholders:
     * - `TABLE_NAME`: The name of the table
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * @default "{{ TABLE_NAME | pascal-case }}_PrimaryKey"
     */
    primaryKeyTypeName: string;
    /**
     * Where should primary key types be located in the generated code
     *
     * You may use the following placeholders:
     * - `TABLE_NAME`: The name of the table
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts"
     */
    primaryKeyFileName: string;
    /**
     * What should table types be called in the generated code
     *
     * You may use the following placeholders:
     * - `TABLE_NAME`: The name of the table
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * @default "{{ TABLE_NAME | pascal-case }}"
     */
    tableTypeName: string;
    /**
     * Where should table types be located in the generated code
     *
     * You may use the following placeholders:
     * - `TABLE_NAME`: The name of the table
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts"
     */
    tableFileName: string;
    /**
     * What should table data be called in the generated code
     *
     * You may use the following placeholders:
     * - `TABLE_NAME`: The name of the table
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * @default "{{ TABLE_NAME | pascal-case }}_Data"
     */
    tableDataTypeName: string;
    /**
     * Where should table data be located in the generated code
     *
     * You may use the following placeholders:
     * - `TABLE_NAME`: The name of the table
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts"
     */
    tableDataFileName: string;
    /**
     * What should table insert parameter types be called in the generated code
     *
     * You may use the following placeholders:
     * - `TABLE_NAME`: The name of the table
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * @default "{{ TABLE_NAME | pascal-case }}_InsertParameters"
     */
    tableInsertParametersTypeName: string;
    /**
     * Where should table insert parameter types be located in the generated code
     *
     * You may use the following placeholders:
     * - `TABLE_NAME`: The name of the table
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts"
     */
    tableInsertParametersFileName: string;
    /**
     * What should table insert parameter data be called in the generated code
     *
     * You may use the following placeholders:
     * - `TABLE_NAME`: The name of the table
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * @default "{{ TABLE_NAME | pascal-case }}_InsertParameters_Data"
     */
    tableInsertParametersDataTypeName: string;
    /**
     * Where should table insert parameter data be located in the generated code
     *
     * You may use the following placeholders:
     * - `TABLE_NAME`: The name of the table
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}/{{ TABLE_NAME }}.ts"
     */
    tableInsertParametersDataFileName: string;
    /**
     * What should schema types be called in the generated code
     *
     * You may use the following placeholders:
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * @default "{{ SCHEMA_NAME | pascal-case }}"
     */
    schemaTypeName: string;
    /**
     * Where should schema types be located in the generated code
     *
     * You may use the following placeholders:
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}.ts"
     */
    schemaFileName: string;
    /**
     * What should schema data be called in the generated code
     *
     * You may use the following placeholders:
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * @default "{{ SCHEMA_NAME | pascal-case }}_Data"
     */
    schemaDataTypeName: string;
    /**
     * Where should schema data be located in the generated code
     *
     * You may use the following placeholders:
     * - `SCHEMA_NAME`: The name of the schema
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "databases/{{ DATABASE_NAME }}/{{ SCHEMA_NAME }}.ts"
     */
    schemaDataFileName: string;
    /**
     * What should database types be called in the generated code
     *
     * You may use the following placeholders:
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * @default "{{ DATABASE_NAME | pascal-case }}"
     */
    databaseTypeName: string;
    /**
     * Where should database types be located in the generated code
     *
     * You may use the following placeholders:
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "databases/{{ DATABASE_NAME }}.ts"
     */
    databaseFileName: string;
    /**
     * What should database data be called in the generated code
     *
     * You may use the following placeholders:
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * @default "{{ DATABASE_NAME | pascal-case }}_Data"
     */
    databaseDataTypeName: string;
    /**
     * Where should database data be located in the generated code
     *
     * You may use the following placeholders:
     * - `DATABASE_NAME`: The name of the database
     *
     * You may use the following formatters: (You can use more than one at a time)
     * - `pascal-case`: Capitalize the first letter of each word
     * - `camel-case`: Capitalize the first letter of each word, except for the first word
     * - `plural`: Add an "s" to the end of the type name
     * - `singular`: Remove the "s" from the end of the type name
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "databases/{{ DATABASE_NAME }}.ts"
     */
    databaseDataFileName: string;
    /**
     * What should the full export of the databases types be called in the generated code
     *
     * @default "Databases"
     */
    fullExportTypeName: string;
    /**
     * Where should the full export of the databases types be located in the generated code
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "index.ts"
     */
    fullExportFileName: string;
    /**
     * What should the full export of the databases data be called in the generated code
     *
     * @default "Databases_Data"
     */
    fullExportDataTypeName: string;
    /**
     * Where should the full export of the databases data be located in the generated code
     *
     * Note: .ts is automatically appended to the end of the path (unless you include it yourself)
     *
     * @default "index.ts"
     */
    fullExportDataFileName: string;
    /**
     * Override column types for some columns. The name can be either:
     *
     * - "table_name.column_name"
     * - "schema_name.table_name.column_name"
     *
     * @default {}
     */
    columnTypeOverrides: {
        [x: string]: string | undefined;
    };
    /**
     * Override generated TypeScript types for some types. The name can be either:
     *
     * - key of OID
     * - value of OID
     * - "custom_type_name"
     * - "schema_name.custom_type_name"
     *
     * @default {}
     *
     * OID:
     * @link https://github.com/PostgreSQL-Typed/PostgreSQL-Typed/blob/main/packages/oids/src/OIDs.ts
     */
    typeOverrides: {
        [x: string]: string | undefined;
    };
    /**
     * Override column parsers for some columns. The name can be either:
     *
     * - "table_name.column_name"
     * - "schema_name.table_name.column_name"
     *
     * @default {}
     */
    columnParserOverrides: {
        [x: string]: [string, ImportStatement[]] | undefined;
    };
    /**
     * Override generated parsers for some types. The name can be either:
     *
     * - key of OID
     * - value of OID
     * - "custom_type_name"
     * - "schema_name.custom_type_name"
     *
     * @default {}
     *
     * OID:
     * @link https://github.com/PostgreSQL-Typed/PostgreSQL-Typed/blob/main/packages/oids/src/OIDs.ts
     */
    parserOverrides: {
        [x: string]: [string, ImportStatement[]] | undefined;
    };
}
export declare const zTypesConfig: z.ZodObject<{
    directory: z.ZodDefault<z.ZodString>;
    debug: z.ZodDefault<z.ZodBoolean>;
    debugFileName: z.ZodDefault<z.ZodString>;
    domainTypeName: z.ZodDefault<z.ZodString>;
    domainFileName: z.ZodDefault<z.ZodString>;
    domainDataTypeName: z.ZodDefault<z.ZodString>;
    domainDataFileName: z.ZodDefault<z.ZodString>;
    enumTypeName: z.ZodDefault<z.ZodString>;
    enumFileName: z.ZodDefault<z.ZodString>;
    primaryKeyTypeName: z.ZodDefault<z.ZodString>;
    primaryKeyFileName: z.ZodDefault<z.ZodString>;
    tableTypeName: z.ZodDefault<z.ZodString>;
    tableFileName: z.ZodDefault<z.ZodString>;
    tableDataTypeName: z.ZodDefault<z.ZodString>;
    tableDataFileName: z.ZodDefault<z.ZodString>;
    tableInsertParametersTypeName: z.ZodDefault<z.ZodString>;
    tableInsertParametersFileName: z.ZodDefault<z.ZodString>;
    tableInsertParametersDataTypeName: z.ZodDefault<z.ZodString>;
    tableInsertParametersDataFileName: z.ZodDefault<z.ZodString>;
    schemaTypeName: z.ZodDefault<z.ZodString>;
    schemaFileName: z.ZodDefault<z.ZodString>;
    schemaDataTypeName: z.ZodDefault<z.ZodString>;
    schemaDataFileName: z.ZodDefault<z.ZodString>;
    databaseTypeName: z.ZodDefault<z.ZodString>;
    databaseFileName: z.ZodDefault<z.ZodString>;
    databaseDataTypeName: z.ZodDefault<z.ZodString>;
    databaseDataFileName: z.ZodDefault<z.ZodString>;
    fullExportTypeName: z.ZodDefault<z.ZodString>;
    fullExportFileName: z.ZodDefault<z.ZodString>;
    fullExportDataTypeName: z.ZodDefault<z.ZodString>;
    fullExportDataFileName: z.ZodDefault<z.ZodString>;
    columnTypeOverrides: z.ZodDefault<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodString>>>;
    typeOverrides: z.ZodDefault<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodString>>>;
    columnParserOverrides: z.ZodDefault<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodTuple<[z.ZodString, z.ZodArray<z.ZodObject<{
        module: z.ZodString;
        name: z.ZodString;
        as: z.ZodOptional<z.ZodString>;
        type: z.ZodUnion<[z.ZodLiteral<"default">, z.ZodLiteral<"named">]>;
        isType: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        as?: string | undefined;
        isType?: boolean | undefined;
        type: "default" | "named";
        module: string;
        name: string;
    }, {
        as?: string | undefined;
        isType?: boolean | undefined;
        type: "default" | "named";
        module: string;
        name: string;
    }>, "many">], null>>>>;
    parserOverrides: z.ZodDefault<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodTuple<[z.ZodString, z.ZodArray<z.ZodObject<{
        module: z.ZodString;
        name: z.ZodString;
        as: z.ZodOptional<z.ZodString>;
        type: z.ZodUnion<[z.ZodLiteral<"default">, z.ZodLiteral<"named">]>;
        isType: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        as?: string | undefined;
        isType?: boolean | undefined;
        type: "default" | "named";
        module: string;
        name: string;
    }, {
        as?: string | undefined;
        isType?: boolean | undefined;
        type: "default" | "named";
        module: string;
        name: string;
    }>, "many">], null>>>>;
}, "strip", z.ZodTypeAny, {
    debug: boolean;
    directory: string;
    debugFileName: string;
    domainTypeName: string;
    domainFileName: string;
    domainDataTypeName: string;
    domainDataFileName: string;
    enumTypeName: string;
    enumFileName: string;
    primaryKeyTypeName: string;
    primaryKeyFileName: string;
    tableTypeName: string;
    tableFileName: string;
    tableDataTypeName: string;
    tableDataFileName: string;
    tableInsertParametersTypeName: string;
    tableInsertParametersFileName: string;
    tableInsertParametersDataTypeName: string;
    tableInsertParametersDataFileName: string;
    schemaTypeName: string;
    schemaFileName: string;
    schemaDataTypeName: string;
    schemaDataFileName: string;
    databaseTypeName: string;
    databaseFileName: string;
    databaseDataTypeName: string;
    databaseDataFileName: string;
    fullExportTypeName: string;
    fullExportFileName: string;
    fullExportDataTypeName: string;
    fullExportDataFileName: string;
    columnTypeOverrides: Record<string, string | undefined>;
    typeOverrides: Record<string, string | undefined>;
    columnParserOverrides: Record<string, [string, {
        as?: string | undefined;
        isType?: boolean | undefined;
        type: "default" | "named";
        module: string;
        name: string;
    }[]] | undefined>;
    parserOverrides: Record<string, [string, {
        as?: string | undefined;
        isType?: boolean | undefined;
        type: "default" | "named";
        module: string;
        name: string;
    }[]] | undefined>;
}, {
    debug?: boolean | undefined;
    directory?: string | undefined;
    debugFileName?: string | undefined;
    domainTypeName?: string | undefined;
    domainFileName?: string | undefined;
    domainDataTypeName?: string | undefined;
    domainDataFileName?: string | undefined;
    enumTypeName?: string | undefined;
    enumFileName?: string | undefined;
    primaryKeyTypeName?: string | undefined;
    primaryKeyFileName?: string | undefined;
    tableTypeName?: string | undefined;
    tableFileName?: string | undefined;
    tableDataTypeName?: string | undefined;
    tableDataFileName?: string | undefined;
    tableInsertParametersTypeName?: string | undefined;
    tableInsertParametersFileName?: string | undefined;
    tableInsertParametersDataTypeName?: string | undefined;
    tableInsertParametersDataFileName?: string | undefined;
    schemaTypeName?: string | undefined;
    schemaFileName?: string | undefined;
    schemaDataTypeName?: string | undefined;
    schemaDataFileName?: string | undefined;
    databaseTypeName?: string | undefined;
    databaseFileName?: string | undefined;
    databaseDataTypeName?: string | undefined;
    databaseDataFileName?: string | undefined;
    fullExportTypeName?: string | undefined;
    fullExportFileName?: string | undefined;
    fullExportDataTypeName?: string | undefined;
    fullExportDataFileName?: string | undefined;
    columnTypeOverrides?: Record<string, string | undefined> | undefined;
    typeOverrides?: Record<string, string | undefined> | undefined;
    columnParserOverrides?: Record<string, [string, {
        as?: string | undefined;
        isType?: boolean | undefined;
        type: "default" | "named";
        module: string;
        name: string;
    }[]] | undefined> | undefined;
    parserOverrides?: Record<string, [string, {
        as?: string | undefined;
        isType?: boolean | undefined;
        type: "default" | "named";
        module: string;
        name: string;
    }[]] | undefined> | undefined;
}>;
